The previous inline comment stated that a size of zero would make the
ashmem_read_iter function return EOF, but it returned 0 instead.

Looking at other functions, such as ashmem_llseek or ashmem_mmap, it
appears the convention is to return -EINVAL if the region size is unset or
zero.

To be consistent with the checks, I changed the one occurrence that used
the ! operator to compare the size to check against equal-to-zero instead.

Signed-off-by: Christopher N. Hesse <rayma...@gmail.com>
---
 drivers/staging/android/ashmem.c | 8 +++++---
 1 file changed, 5 insertions(+), 3 deletions(-)

diff --git a/drivers/staging/android/ashmem.c b/drivers/staging/android/ashmem.c
index 74d497d39c5a..6af8130db0d7 100644
--- a/drivers/staging/android/ashmem.c
+++ b/drivers/staging/android/ashmem.c
@@ -291,9 +291,11 @@ static ssize_t ashmem_read_iter(struct kiocb *iocb, struct 
iov_iter *iter)
 
        mutex_lock(&ashmem_mutex);
 
-       /* If size is not set, or set to 0, always return EOF. */
-       if (asma->size == 0)
+       /* If size is not set, or set to 0, always return EINVAL. */
+       if (asma->size == 0) {
+               ret = -EINVAL;
                goto out_unlock;
+       }
 
        if (!asma->file) {
                ret = -EBADF;
@@ -359,7 +361,7 @@ static int ashmem_mmap(struct file *file, struct 
vm_area_struct *vma)
        mutex_lock(&ashmem_mutex);
 
        /* user needs to SET_SIZE before mapping */
-       if (!asma->size) {
+       if (asma->size == 0) {
                ret = -EINVAL;
                goto out;
        }
-- 
2.23.0

_______________________________________________
devel mailing list
de...@linuxdriverproject.org
http://driverdev.linuxdriverproject.org/mailman/listinfo/driverdev-devel

Reply via email to